Security Advisories (3)
CPANSA-Jifty-2011-01 (2011-03-17)

The path as passed in the fragment request data structure was used verbatim in the dispatcher and other locations. This possibly allowed requests to walk around ACLs by requesting '/some/safe/place/../../../dangerous' as a fragment.

CPANSA-Jifty-2009-01 (2009-04-09)

The REST plugin would let you call any method on the model.

CPANSA-Jifty-2008-01 (2009-04-08)

Allowed all actions on GET.

NAME

Jifty::Script::Plugin - Create the skeleton of a Jifty plugin

DESCRIPTION

Creates a skeleton of a new Jifty::Plugin.

options

This script only takes one option, --name, which is required; it is the name of the plugin to create; this will be prefixed with Jifty::Plugin:: automatically. Jifty will create a directory with that name, and place all of the files it creates inside that directory.

run

Create a directory for the plugin, a skeleton directory structure, and a Makefile.PL for your plugin.